Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(81)

Unified Diff: chrome/common/sync_util.cc

Issue 1257633002: Componentize VersionInfo. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix OWNERS (copy from //chrome/OWNERS) Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/common/sync_util.cc
diff --git a/chrome/common/sync_util.cc b/chrome/common/sync_util.cc
index 3cda52192ff32438818010c1139ad58cc292d88c..7dee479c492d539addeb9e7570f6d752ec763f13 100644
--- a/chrome/common/sync_util.cc
+++ b/chrome/common/sync_util.cc
@@ -12,18 +12,18 @@
namespace {
-// Converts VersionInfo::Channel to string for user-agent string.
-std::string ChannelToString(chrome::VersionInfo::Channel channel) {
+// Converts version_info::Channel to string for user-agent string.
+std::string ChannelToString(version_info::Channel channel) {
switch (channel) {
- case chrome::VersionInfo::CHANNEL_UNKNOWN:
+ case version_info::CHANNEL_UNKNOWN:
return "unknown";
- case chrome::VersionInfo::CHANNEL_CANARY:
+ case version_info::CHANNEL_CANARY:
return "canary";
- case chrome::VersionInfo::CHANNEL_DEV:
+ case version_info::CHANNEL_DEV:
return "dev";
- case chrome::VersionInfo::CHANNEL_BETA:
+ case version_info::CHANNEL_BETA:
return "beta";
- case chrome::VersionInfo::CHANNEL_STABLE:
+ case version_info::CHANNEL_STABLE:
return "stable";
default:
NOTREACHED();
@@ -45,9 +45,9 @@ GURL GetSyncServiceURL(const base::CommandLine& command_line) {
// will go to the standard sync servers.
GURL result(internal::kSyncDevServerUrl);
- chrome::VersionInfo::Channel channel = chrome::VersionInfo::GetChannel();
- if (channel == chrome::VersionInfo::CHANNEL_STABLE ||
- channel == chrome::VersionInfo::CHANNEL_BETA) {
+ version_info::Channel channel = chrome::VersionInfo::GetChannel();
+ if (channel == version_info::CHANNEL_STABLE ||
+ channel == version_info::CHANNEL_BETA) {
result = GURL(internal::kSyncServerUrl);
}

Powered by Google App Engine
This is Rietveld 408576698